@@ -18,14 +18,11 @@
 from __future__ import annotations
 
 import re
-import sys
 import warnings
 from datetime import timedelta
 from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
-import boto3
-
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
@@ -43,6 +40,8 @@ from airflow.providers.amazon.aws.utils.task_log_fetcher import AwsTaskLogFetche
 from airflow.utils.helpers import prune_dict
 
 if TYPE_CHECKING:
+    import boto3
+
     from airflow.models import TaskInstance
     from airflow.utils.context import Context
 
@@ -476,7 +475,9 @@ class EcsRunTaskOperator(EcsBaseOperator):
         number_logs_exception: int = 10,
         wait_for_completion: bool = True,
         waiter_delay: int = 6,
-        waiter_max_attempts: int = 100,
+        waiter_max_attempts: int = 1000000 * 365 * 24 * 60 * 10,
+        # Set the default waiter duration to 1M years (attempts*delay)
+        # Airflow execution_timeout handles task timeout
         deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
         **kwargs,
     ):
@@ -665,7 +666,6 @@ class EcsRunTaskOperator(EcsBaseOperator):
             return
 
         waiter = self.client.get_waiter("tasks_stopped")
-        waiter.config.max_attempts = sys.maxsize  # timeout is managed by airflow
         waiter.wait(
             cluster=self.cluster,
             tasks=[self.arn],
