@@ -17,12 +17,16 @@
 # under the License.
 from __future__ import annotations
 
+from datetime import timedelta
 from functools import cached_property
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from deprecated import deprecated
 
+from airflow.configuration import conf
+from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.glue_catalog import GlueCatalogHook
+from airflow.providers.amazon.aws.triggers.glue import GlueCatalogPartitionTrigger
 from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
@@ -48,6 +52,9 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
     :param database_name: The name of the catalog database where the partitions reside.
     :param poke_interval: Time in seconds that the job should wait in
         between each tries
+    :param deferrable: If true, then the sensor will wait asynchronously for the partition to
+        show up in the AWS Glue Catalog.
+        (default: False, but can be overridden in config file by setting default_deferrable to True)
     """
 
     template_fields: Sequence[str] = (
@@ -66,6 +73,7 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
         region_name: str | None = None,
         database_name: str = "default",
         poke_interval: int = 60 * 3,
+        deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
         **kwargs,
     ):
         super().__init__(poke_interval=poke_interval, **kwargs)
@@ -74,9 +82,26 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
         self.table_name = table_name
         self.expression = expression
         self.database_name = database_name
+        self.deferrable = deferrable
+
+    def execute(self, context: Context) -> Any:
+        if self.deferrable:
+            self.defer(
+                trigger=GlueCatalogPartitionTrigger(
+                    database_name=self.database_name,
+                    table_name=self.table_name,
+                    expression=self.expression,
+                    aws_conn_id=self.aws_conn_id,
+                    waiter_delay=int(self.poke_interval),
+                ),
+                method_name="execute_complete",
+                timeout=timedelta(seconds=self.timeout),
+            )
+        else:
+            super().execute(context=context)
 
     def poke(self, context: Context):
-        """Checks for existence of the partition in the AWS Glue Catalog table."""
+        """Check for existence of the partition in the AWS Glue Catalog table."""
         if "." in self.table_name:
             self.database_name, self.table_name = self.table_name.split(".")
         self.log.info(
@@ -85,9 +110,14 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
 
         return self.hook.check_for_partition(self.database_name, self.table_name, self.expression)
 
+    def execute_complete(self, context: Context, event: dict | None = None) -> None:
+        if event is None or event["status"] != "success":
+            raise AirflowException(f"Trigger error: event is {event}")
+        self.log.info("Partition exists in the Glue Catalog")
+
     @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> GlueCatalogHook:
-        """Gets the GlueCatalogHook."""
+        """Get the GlueCatalogHook."""
         return self.hook
 
     @cached_property
