@@ -18,18 +18,20 @@
 from __future__ import annotations
 
 import asyncio
-from typing import Any, AsyncIterator
+from typing import TYPE_CHECKING, Any, AsyncIterator
 
 from botocore.exceptions import ClientError, WaiterError
 
 from airflow import AirflowException
-from airflow.providers.amazon.aws.hooks.base_aws import AwsGenericHook
 from airflow.providers.amazon.aws.hooks.ecs import EcsHook
 from airflow.providers.amazon.aws.hooks.logs import AwsLogsHook
 from airflow.providers.amazon.aws.triggers.base import AwsBaseWaiterTrigger
 from airflow.providers.amazon.aws.utils.task_log_fetcher import AwsTaskLogFetcher
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 
+if TYPE_CHECKING:
+    from airflow.providers.amazon.aws.hooks.base_aws import AwsGenericHook
+
 
 class ClusterActiveTrigger(AwsBaseWaiterTrigger):
     """
@@ -159,10 +161,11 @@ class TaskDoneTrigger(BaseTrigger):
         )
 
     async def run(self) -> AsyncIterator[TriggerEvent]:
-        # fmt: off
-        async with EcsHook(aws_conn_id=self.aws_conn_id, region_name=self.region).async_conn as ecs_client,\
-                AwsLogsHook(aws_conn_id=self.aws_conn_id, region_name=self.region).async_conn as logs_client:
-            # fmt: on
+        async with EcsHook(
+            aws_conn_id=self.aws_conn_id, region_name=self.region
+        ).async_conn as ecs_client, AwsLogsHook(
+            aws_conn_id=self.aws_conn_id, region_name=self.region
+        ).async_conn as logs_client:
             waiter = ecs_client.get_waiter("tasks_stopped")
             logs_token = None
             while self.waiter_max_attempts:
